@@ -39,12 +39,21 @@ quint32 Device::activePortIndex() const
     return d->m_activePortIndex;
 }
 
-    
 qint64 Device::baseVolume() const
 {
     return d->m_baseVolume;
 }
 
+QVariantMap Device::pulseProperties() const
+{
+    return d->m_pulseProperties;
+}
+
+bool Device::isVirtualDevice() const
+{
+    return d->m_virtualDevice;
+}
+
 Device::Device(QObject *parent)
     : VolumeObject(parent)
     , d(new DevicePrivate(this))
