@@ -9,7 +9,7 @@
 #include <pulse/proplist.h>
 
 #include <QHash>
-#include <QVector>
+#include <QList>
 
 #include "device.h"
 #include "port.h"
@@ -32,9 +32,26 @@ public:
     quint32 m_activePortIndex = -1;
     Device::State m_state = Device::UnknownState;
     qint64 m_baseVolume = -1;
+    QVariantMap m_pulseProperties;
+    bool m_virtualDevice = false;
 
     Device::State stateFromPaState(int value) const;
 
+    template<typename PAInfo>
+    void updatePulseProperties(const PAInfo *info)
+    {
+        QVariantMap pulseProperties;
+        void *state = nullptr;
+        while (auto key = pa_proplist_iterate(info->proplist, &state)) {
+            const auto value = pa_proplist_gets(info->proplist, key);
+            pulseProperties.insert(key, QString::fromUtf8(value));
+        }
+        if (pulseProperties != m_pulseProperties) {
+            m_pulseProperties = pulseProperties;
+            Q_EMIT q->pulsePropertiesChanged();
+        }
+    }
+
     template<typename PAInfo>
     void updateDevice(const PAInfo *info)
     {
@@ -56,11 +73,13 @@ public:
         m_cardIndex = info->card;
         Q_EMIT q->cardIndexChanged();
 
+        updatePulseProperties(info);
+
         QStringList newPorts;
         QStringList existingPorts;
 
         // Build list of existing ports
-        for (const Port *port : qAsConst(m_ports)) {
+        for (const Port *port : std::as_const(m_ports)) {
             existingPorts << port->name();
         }
 
@@ -82,7 +101,7 @@ public:
         }
 
         // Remove ports that are not in the updated port list
-        for (Port *port : qAsConst(m_ports)) {
+        for (Port *port : std::as_const(m_ports)) {
             if (!newPorts.contains(port->name())) {
                 m_ports.removeOne(port);
                 delete port;
@@ -90,7 +109,7 @@ public:
         }
 
         // Set active port
-        for (Port *port : qAsConst(m_ports)) {
+        for (Port *port : std::as_const(m_ports)) {
             if (info->active_port->name == port->name()) {
                 m_activePortIndex = m_ports.indexOf(port);
             }
@@ -109,6 +128,12 @@ public:
             m_baseVolume = info->base_volume;
             Q_EMIT q->baseVolumeChanged();
         }
+
+        const bool isVirtual = !(info->flags & 4); // PA_X_HARDWARE
+        if (m_virtualDevice != isVirtual) {
+            m_virtualDevice = isVirtual;
+            Q_EMIT q->virtualDeviceChanged();
+        }
     }
 };
 
