@@ -17,7 +17,9 @@
 
 #include "card_p.h"
 #include "client_p.h"
+#include "debug_object.h"
 #include "module_p.h"
+#include "pulseobject_p.h"
 #include "sink_p.h"
 #include "sinkinput_p.h"
 #include "source_p.h"
@@ -50,6 +52,14 @@ public:
     virtual QObject *objectAt(int index) const = 0;
     virtual int indexOfObject(QObject *object) const = 0;
 
+    void disconnectSignals()
+    {
+        disconnect(this, &MapBaseQObject::aboutToBeAdded, nullptr, nullptr);
+        disconnect(this, &MapBaseQObject::added, nullptr, nullptr);
+        disconnect(this, &MapBaseQObject::aboutToBeRemoved, nullptr, nullptr);
+        disconnect(this, &MapBaseQObject::removed, nullptr, nullptr);
+    };
+
 Q_SIGNALS:
     void aboutToBeAdded(int index);
     void added(int index, QObject *object);
@@ -122,13 +132,19 @@ public:
         }
 
         auto *obj = m_hash.value(info->index);
+        auto type = QLatin1String("create");
         if (!obj) {
             obj = new Type(parent);
             obj->d->update(info);
             insert(obj);
         } else {
+            type = QLatin1String("create");
             obj->d->update(info);
         }
+
+#if !defined(UNDER_TEST)
+        qCDebug(PAOBJECT).noquote() << type << qobject_cast<PulseObject *>(obj)->d;
+#endif
     }
 
     void removeEntry(quint32 index)
