@@ -21,13 +21,13 @@ class PULSEAUDIOQT_EXPORT SourceOutput : public Stream
     Q_OBJECT
 
 public:
-    ~SourceOutput();
+    ~SourceOutput() override;
 
     void setVolume(qint64 volume) override;
     void setMuted(bool muted) override;
     void setChannelVolume(int channel, qint64 volume) override;
     void setDeviceIndex(quint32 deviceIndex) override;
-    void setChannelVolumes(const QVector<qint64> &channelVolumes) override;
+    void setChannelVolumes(const QList<qint64> &channelVolumes) override;
 
 private:
     explicit SourceOutput(QObject *parent);
